﻿

'
'/**
'--------------------------------------------------
' Versión .....: 2013/02/19
'               [dd/mm/aaaa] 
' Original en .: Util
'--------------------------------------------------
'
'
' -------------------------------------------------
' Clase ....: InvalidCadenaNumericaException
' Lenguaje .: (.NET Framework 4.0) - Microsoft Visual Basic .NET 2010 - [2010]
' Autor ....:  - aguila7 - Joaquin
' Emilio ...: mailto:joaquin@medina.name
'
' DESCRIPCION.:
'     Clase personalizada para recoger el error de cadena  numerica mal formada
'     se produce cuando la cadena numerica no esta formada de acuerdo al formato numerico español
'
' OBSERVACIONES.:
'    
'
' BIBLIOGRAFIA.:
'     http://msdn.microsoft.com/es-es/library/system.applicationexception(v=VS.100).aspx
'     http://msdn.microsoft.com/es-es/library/system.exception.aspx
'     Si está diseñando una aplicación que necesita crear sus propias excepciones, 
'     se le aconseja que derive las excepciones personalizadas de la  
'     clase Exception.
'     Originalmente se pensaba que las excepciones personalizadas  
'     debían derivar de la clase ApplicationException; sin embargo, en la
'     práctica, no se ha encontrado que esto agregue un valor significativo.
'     http://msdn.microsoft.com/es-es/library/seyhszts.aspx
'     http://msdn.microsoft.com/es-es/library/87cdya3t.aspx
'
'
' HERENCIA.:
'     System.Object
'        System.Exception
'
' MODIFICACIONES  [aaaa-mm-dd] 
' - 2013/02/19- Creación 
' - 2013/02/19 - Revisado con FxCop 
' - 
' -------------------------------------------------
'
'*/
'
'
' -------------------------------------------------
Option Explicit On
Option Strict On
Option Infer Off
Option Compare Binary



''' <summary>
'''   Clase que encapsula el error que se produce cuando el número 
'''   contenido en la cadena no se ajusta al formato numerico español
''' </summary>
''' <remarks>
''' http://msdn.microsoft.com/en-us/library/ms229064(VS.80).aspx
''' </remarks>
<Serializable()> _
Public Class InvalidCadenaNumericaException
    Inherits Exception

    ''' <summary>
    ''' Constructor
    ''' </summary>
    Public Sub New()
        MyBase.New()
    End Sub


    ''' <summary>
    ''' Inicializa una nueva instancia con un mensaje de error
    ''' </summary>
    ''' <param name="message">El mensaje que describe el error.</param>
    Public Sub New(ByVal message As String, ByVal cadenaNumericaErronea As String)
        MyBase.New(message & _
            Environment.NewLine & _
            "La cadena numérica recibida tiene caracteres incompatibles con el formato numérico español:" & _
            Environment.NewLine & _
            "Cadena con el error [" & cadenaNumericaErronea & "] " & _
            Environment.NewLine & _
            "Características del formato numérico español" & _
            Environment.NewLine & _
            " * El numero solo puede contener dígitos" & _
            Environment.NewLine & _
            " * El separador de millares es o bien el punto(.) o bien el espacio (' ')" & _
            Environment.NewLine & _
            " * El separador decimal es la coma(,)" & _
            Environment.NewLine & _
            " * Debe estar escrito en una única línea de texto" & _
            Environment.NewLine)
    End Sub




    ''' <summary>
    ''' Inicializa una nueva instancia con un mensaje de error
    ''' </summary>
    ''' <param name="message">El mensaje que describe el error.</param>
    Public Sub New(ByVal message As String)
        MyBase.New(message)

    End Sub

    ''' <summary>
    ''' Inicializa una nueva instancia con una referencia
    ''' a la excepcion que es causa de esta excepcion
    ''' </summary>
    ''' <param name="innerException">
    ''' La escepcion que es el origen de que se cree esta excepcion
    ''' o una referencia (null)
    ''' </param>
    Public Sub New(ByVal innerException As Exception)
        MyBase.New(Nothing, innerException)
    End Sub

    ''' <summary>
    ''' Inicializa una instancia con un mensaje de error especifico
    ''' y una referencia al objeto Excepcion que es la causa de esta excepcion
    ''' </summary>
    ''' <param name="message">El mensaje que describe el error.</param>
    ''' <param name="innerException">
    ''' La escepcion que es el origen de que se cree esta excepcion
    ''' o una referencia (null)
    ''' </param>
    Public Sub New(ByVal message As String, ByVal innerException As Exception)
        MyBase.New(message, innerException)
    End Sub


    ''' <summary>
    '''   Constructor de serializacion
    '''   Inicializa una nueva instancia de la clase a partir de datos serializados. 
    ''' </summary>
    ''' <param name="info">Objeto que contiene los datos serializados.</param>
    ''' <param name="context">nformación contextual acerca del origen o el destino de la excepción.</param>
    ''' <remarks><code>http://msdn.microsoft.com/es-ES/library/ms182343.aspx</code></remarks>
    Protected Sub New(ByVal info As Runtime.Serialization.SerializationInfo, ByVal context As Runtime.Serialization.StreamingContext)
        '---------------------------------------------------------
        ' ¡ATENCION!  regla FxCop
        'CA2229: Implementar constructores de serialización
        'http://msdn.microsoft.com/es-ES/library/ms182343.aspx
        'CA1032: Implementar constructores de excepción estándar
        'http://msdn.microsoft.com/library/ms182151(VS.100).aspx
        '---------------------------------------------------------
        MyBase.New(info, context)
    End Sub

End Class

